========================
Changes in version 1.6.0
========================

FFC 1.6.0 was released on 2015-07-28.

- Rename and modify a number of UFC interface functions. See
  docstrings in ufc.h for details.
- Bump required SWIG version to 3.0.3
- Disable dual basis (``tabulate_coordinates`` and ``evaluate_dofs``)
  for enriched elements until correct implementation is brought up
